@@ -1,6 +1,6 @@
 /* atmarp.c - RFC1577 ATMARP control */
  
-/* Written 1995-1998 by Werner Almesberger, EPFL-LRC/ICA */
+/* Written 1995-1999 by Werner Almesberger, EPFL-LRC/ICA */
 
 
 #include <stdlib.h>
@@ -102,11 +102,11 @@ static void usage(const char *name)
 {
     fprintf(stderr,"usage: %s -a\n",name);
     fprintf(stderr,"%6s %s -c [[atm]N]\n","",name);
-    fprintf(stderr,"%6s %s -q ip_addr qos_spec\n","",name);
+    fprintf(stderr,"%6s %s -q ip_addr [qos qos_spec] [sndbuf bytes]\n","",name);
     fprintf(stderr,"%6s %s -s ip_addr [itf.]vpi.vci [pcr value] [qos spec] "
-      "[temp] [pub]\n%8s [null]\n","",name,"");
-    fprintf(stderr,"%6s %s -s ip_addr atm_addr [pcr value] [qos spec] [temp] "
-      "[pub] [arpsrv]\n","",name);
+      "[sndbuf bytes]\n%8s [temp] [pub] [null]\n","",name,"");
+    fprintf(stderr,"%6s %s -s ip_addr atm_addr [pcr value] [qos spec] "
+      "[sndbuf bytes] [temp]\n%8s [pub] [arpsrv]\n","",name,"");
     fprintf(stderr,"%6s %s -d ip_addr [arpsrv]\n","",name);
 #if 0  /* undocumented */
     fprintf(stderr,"%6s %s -Q ip_addr\n","",name);
@@ -169,7 +169,7 @@ int main(int argc,char **argv)
 	    if (req.itf == -1) printf("atm%d\n",num);
 	    return 0;
 	case art_qos:
-	    if (argc > optind+2) usage(argv[0]);
+	    if (argc < optind+1) usage(argv[0]);
 	    /* fall through */
 	case art_set:
 	    if (argc < optind+2) usage(argv[0]);
@@ -186,10 +186,25 @@ int main(int argc,char **argv)
     req.ip = text2ip(argv[optind],NULL,T2I_NAME | T2I_ERROR);
     if (req.ip == INADDR_NONE) return 1;
     req.flags = ATF_PERM;
-    if (req.type == art_qos)
-	if (text2qos(argv[optind+1],&req.qos,0)) usage(argv[0]);
+    if (req.type == art_qos) {
+	memset(&req.qos,0,sizeof(req.qos));
+	req.sndbuf = 0;
+	for (i = optind+1; i < argc; i++)
+	    if (!strcmp(argv[i],"qos")) {
+		    if (++i >= argc) usage(argv[0]);
+		    if (text2qos(argv[i],&req.qos,0)) usage(argv[0]);
+		}
+	    else if (!strcmp(argv[i],"sndbuf")) {
+		    if (++i >= argc) usage(argv[0]);
+		    req.sndbuf = strtol(argv[i],&end,0);
+		    if (*end) usage(argv[0]);
+		}
+	    else if (i != optind+1 || argc != optind+2 ||
+		  text2qos(argv[optind+1],&req.qos,0)) usage(argv[0]);
+    }
     if (req.type == art_set) {
 	memset(&req.qos,0,sizeof(req.qos));
+	req.sndbuf = 0;
 	for (i = optind+2; i < argc; i++)
 	    if (!strcmp(argv[i],"temp")) req.flags &= ~ATF_PERM;
 	    else if (!strcmp(argv[i],"pub")) req.flags |= ATF_PUBL;
@@ -199,6 +214,11 @@ int main(int argc,char **argv)
 		    if (++i >= argc) usage(argv[0]);
 		    if (text2qos(argv[i],&req.qos,0)) usage(argv[0]);
 		}
+	    else if (!strcmp(argv[i],"sndbuf")) {
+		    if (++i >= argc) usage(argv[0]);
+		    req.sndbuf = strtol(argv[i],&end,0);
+		    if (*end) usage(argv[0]);
+		}
 	    else if (!strcmp(argv[i],"pcr")) {
 		    if (++i >= argc) usage(argv[0]);
 		    req.qos.txtp.traffic_class = req.qos.rxtp.traffic_class =
