@@ -26,10 +26,10 @@
 #include <sys/ioctl.h>
 #include <errno.h>
 #include <net/if.h>
+#include <atm.h>
 #include <linux/atmdev.h>
 #include "io.h"
 #include "atmd.h"
-#include "atm.h"
 #include "atmf_uni.h"
 
 #define SNMP_VCI 16
