@@ -14,8 +14,7 @@
 
 static void usage(const char *name)
 {
-    fprintf(stderr,"usage: %s [ -s ] [ -l level ] [ -r level ] [ itf ]\n",
-      name);
+    fprintf(stderr,"usage: %s -s [ -l level ] [ -r level ] [ itf ]\n",name);
     fprintf(stderr,"%7s%s [ itf ]\n","",name);
     fprintf(stderr,"%7s%s -q [ itf ]\n","",name);
     fprintf(stderr,"  levels: aal = AAL PDU, atm = ATM cell,\n");
