@@ -10,7 +10,7 @@
 #include <errno.h>
 #include <assert.h>
 
-#include "atm.h"
+#include <atm.h>
 #include <linux/atmdev.h>
 
 #include "atmd.h"
